@@ -16,13 +16,12 @@
 import pecan
 from oslo_log import log as logging
 
+from designate.api.v2.controllers import rest
+from designate.common import constants
 from designate import exceptions
 from designate import policy
 from designate import utils
-from designate.api.v2.controllers import rest
 from designate.objects.adapters import DesignateAdapter
-from designate.i18n import _LI
-
 
 LOG = logging.getLogger(__name__)
 
@@ -33,7 +32,11 @@ class ZoneExportController(rest.RestController):
     @utils.validate_uuid('export_id')
     def get_all(self, export_id):
         context = pecan.request.environ['context']
-        target = {'tenant_id': context.tenant}
+        if policy.enforce_new_defaults():
+            target = {constants.RBAC_PROJECT_ID: context.project_id}
+        else:
+            target = {'tenant_id': context.project_id}
+
         policy.check('zone_export', context, target)
 
         export = self.central_api.get_zone_export(context, export_id)
@@ -61,7 +64,7 @@ class ZoneExportCreateController(rest.RestController):
             context, zone_id)
         response.status_int = 202
 
-        LOG.info(_LI("Created %(zone_export)s"), {'zone_export': zone_export})
+        LOG.info("Created %(zone_export)s", {'zone_export': zone_export})
 
         zone_export = DesignateAdapter.render(
             'API_v2', zone_export, request=request)
@@ -86,7 +89,7 @@ class ZoneExportsController(rest.RestController):
 
         zone_export = self.central_api.get_zone_export(context, export_id)
 
-        LOG.info(_LI("Retrieved %(export)s"), {'export': zone_export})
+        LOG.info("Retrieved %(export)s", {'export': zone_export})
 
         return DesignateAdapter.render(
             'API_v2',
@@ -110,7 +113,7 @@ class ZoneExportsController(rest.RestController):
         zone_exports = self.central_api.find_zone_exports(
             context, criterion, marker, limit, sort_key, sort_dir)
 
-        LOG.info(_LI("Retrieved %(exports)s"),
+        LOG.info("Retrieved %(exports)s",
                  {'exports': zone_exports})
 
         return DesignateAdapter.render(
@@ -131,7 +134,7 @@ class ZoneExportsController(rest.RestController):
         zone_export = self.central_api.delete_zone_export(
             context, zone_export_id)
 
-        LOG.info(_LI("Deleted %(zone_export)s"), {'zone_export': zone_export})
+        LOG.info("Deleted %(zone_export)s", {'zone_export': zone_export})
 
         response.status_int = 204
 
