@@ -11,11 +11,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import urllib
+
 import netaddr
 import requests
 from oslo_config import cfg
 from oslo_log import log as logging
-from six.moves import urllib
 
 from designate import exceptions
 from designate.backend import base
