@@ -15,14 +15,15 @@ import random
 
 from oslo_log import log as logging
 
-from designate.scheduler.filters.base import Filter
+from designate.scheduler.filters import base
 from designate.objects import PoolList
 
 LOG = logging.getLogger(__name__)
 
 
-class RandomFilter(Filter):
-    """Randomly chooses one of the input pools if there is multiple supplied.
+class RandomFilter(base.Filter):
+    """Randomly chooses one of the input pools if there are multiple
+    ones supplied.
 
     .. note::
 
@@ -35,9 +36,8 @@ class RandomFilter(Filter):
     """
 
     def filter(self, context, pools, zone):
-        new_list = PoolList()
-        if len(pools):
-            new_list.append(random.choice(pools))
-            return new_list
-        else:
-            return pools
+        if pools:
+            new_pool_list = PoolList()
+            new_pool_list.append(random.choice(pools))
+            return new_pool_list
+        return pools
