@@ -256,6 +256,7 @@ class CentralBasic(TestCase):
             'set_rules',
             'init',
             'check',
+            'enforce_new_defaults',
         ])
 
         designate.central.service.quota = mock.NonCallableMock(spec_set=[
@@ -788,13 +789,13 @@ class CentralZoneTestCase(CentralBasic):
     def test_add_ns_creation(self):
         self.service._create_ns = mock.Mock()
 
-        self.service.find_recordsets = mock.Mock(
-            return_value=[]
+        self.service.find_recordset = mock.Mock(
+            side_effect=exceptions.RecordSetNotFound()
         )
 
         self.service._add_ns(
             self.context,
-            RoObject(id=CentralZoneTestCase.zone__id),
+            RoObject(name='foo', id=CentralZoneTestCase.zone__id),
             RoObject(name='bar')
         )
         ctx, zone, records = self.service._create_ns.call_args[0]
@@ -803,16 +804,15 @@ class CentralZoneTestCase(CentralBasic):
     def test_add_ns(self):
         self.service._update_recordset_in_storage = mock.Mock()
 
-        recordsets = [
-            RoObject(records=objects.RecordList.from_list([]), managed=True)
-        ]
-        self.service.find_recordsets = mock.Mock(
-            return_value=recordsets
+        self.service.find_recordset = mock.Mock(
+            return_value=RoObject(
+                records=objects.RecordList.from_list([]), managed=True
+            )
         )
 
         self.service._add_ns(
             self.context,
-            RoObject(id=CentralZoneTestCase.zone__id),
+            RoObject(name='foo', id=CentralZoneTestCase.zone__id),
             RoObject(name='bar')
         )
         ctx, zone, rset = \
@@ -821,29 +821,6 @@ class CentralZoneTestCase(CentralBasic):
         self.assertTrue(rset.records[0].managed)
         self.assertEqual('bar', rset.records[0].data.name)
 
-    def test_add_ns_with_other_ns_rs(self):
-        self.service._update_recordset_in_storage = mock.Mock()
-
-        recordsets = [
-            RoObject(records=objects.RecordList.from_list([]), managed=True),
-            RoObject(records=objects.RecordList.from_list([]), managed=False)
-        ]
-
-        self.service.find_recordsets = mock.Mock(
-            return_value=recordsets
-        )
-
-        self.service._add_ns(
-            self.context,
-            RoObject(id=CentralZoneTestCase.zone__id),
-            RoObject(name='bar')
-        )
-        ctx, zone, rset = \
-            self.service._update_recordset_in_storage.call_args[0]
-        self.assertEqual(1, len(rset.records))
-        self.assertTrue(rset.records[0].managed)
-        self.assertEqual('bar', rset.records[0].data.name)
-
     def test_create_zone_no_servers(self):
         self.service._enforce_zone_quota = mock.Mock()
         self.service._is_valid_zone_name = mock.Mock()
@@ -932,7 +909,7 @@ class CentralZoneTestCase(CentralBasic):
         n, ctx, target = designate.central.service.policy.check.call_args[0]
         self.assertEqual(CentralZoneTestCase.zone__id, target['zone_id'])
         self.assertEqual('foo', target['zone_name'])
-        self.assertEqual('2', target['tenant_id'])
+        self.assertEqual('2', target['project_id'])
 
     def test_get_zone_servers(self):
         self.service.storage.get_zone.return_value = RoObject(
@@ -995,6 +972,7 @@ class CentralZoneTestCase(CentralBasic):
             'set_rules',
             'init',
             'check',
+            'enforce_new_defaults',
         ])
         self.context.abandon = True
         self.service.storage.count_zones.return_value = 0
@@ -1187,7 +1165,7 @@ class CentralZoneTestCase(CentralBasic):
             'zone_id': CentralZoneTestCase.zone__id_2,
             'zone_name': 'example.org.',
             'recordset_id': CentralZoneTestCase.recordset__id,
-            'tenant_id': '2'}, target)
+            'project_id': '2'}, target)
 
     def test_find_recordsets(self):
         self.context = mock.Mock()
@@ -1196,7 +1174,7 @@ class CentralZoneTestCase(CentralBasic):
         self.assertTrue(self.service.storage.find_recordsets.called)
         n, ctx, target = designate.central.service.policy.check.call_args[0]
         self.assertEqual('find_recordsets', n)
-        self.assertEqual({'tenant_id': 't'}, target)
+        self.assertEqual({'project_id': 't'}, target)
 
     def test_find_recordset(self):
         self.context = mock.Mock()
@@ -1205,7 +1183,7 @@ class CentralZoneTestCase(CentralBasic):
         self.assertTrue(self.service.storage.find_recordset.called)
         n, ctx, target = designate.central.service.policy.check.call_args[0]
         self.assertEqual('find_recordset', n)
-        self.assertEqual({'tenant_id': 't'}, target)
+        self.assertEqual({'project_id': 't'}, target)
 
     def test_update_recordset_fail_on_changes(self):
         self.service.storage.get_zone.return_value = RoObject()
@@ -1298,7 +1276,7 @@ class CentralZoneTestCase(CentralBasic):
             'zone_name': 'example.org.',
             'zone_type': 'foo',
             'recordset_id': '9c85d9b0-1e9d-4e99-aede-a06664f1af2e',
-            'tenant_id': '2'}, target)
+            'project_id': '2'}, target)
 
     def test__update_recordset_in_storage(self):
         recordset = mock.Mock()
@@ -1532,7 +1510,7 @@ class CentralZoneTestCase(CentralBasic):
         self.service.count_recordsets(self.context)
         n, ctx, target = designate.central.service.policy.check.call_args[0]
         self.assertEqual('count_recordsets', n)
-        self.assertEqual({'tenant_id': None}, target)
+        self.assertEqual({'project_id': None}, target)
         self.assertEqual(
             {},
             self.service.storage.count_recordsets.call_args[0][1]
@@ -1587,7 +1565,7 @@ class CentralZoneTestCase(CentralBasic):
             'zone_type': 'foo',
             'recordset_id': CentralZoneTestCase.recordset__id,
             'recordset_name': 'rs',
-            'tenant_id': '2'}, target)
+            'project_id': '2'}, target)
 
     def test_create_record_worker(self):
         self._test_create_record()
@@ -1689,7 +1667,7 @@ class CentralZoneTestCase(CentralBasic):
             'record_id': CentralZoneTestCase.record__id,
             'recordset_id': CentralZoneTestCase.recordset__id_2,
             'recordset_name': 'foo',
-            'tenant_id': 2}, target)
+            'project_id': 2}, target)
 
     def test_update_record_fail_on_changes(self):
         self.service.storage.get_zone.return_value = RoObject(
@@ -1789,7 +1767,7 @@ class CentralZoneTestCase(CentralBasic):
             'record_id': 'abc12a-1e9d-4e99-aede-a06664f1af2e',
             'recordset_id': 'abc12a-1e9d-4e99-aede-a06664f1af2e',
             'recordset_name': 'rsn',
-            'tenant_id': 'tid'}, target)
+            'project_id': 'tid'}, target)
 
     def test__update_record_in_storage(self):
         self.service._update_zone_in_storage = mock.Mock()
@@ -1893,7 +1871,7 @@ class CentralZoneTestCase(CentralBasic):
             'record_id': CentralZoneTestCase.record__id_2,
             'recordset_id': CentralZoneTestCase.recordset__id_2,
             'recordset_name': 'rsn',
-            'tenant_id': 'tid'}, target)
+            'project_id': 'tid'}, target)
 
     def test_delete_record_in_storage(self):
         self.service._delete_record_in_storage(
@@ -1911,7 +1889,7 @@ class CentralZoneTestCase(CentralBasic):
         self.service.count_records(self.context)
         t, ctx, target = designate.central.service.policy.check.call_args[0]
         self.assertEqual('count_records', t)
-        self.assertEqual({'tenant_id': None}, target)
+        self.assertEqual({'project_id': None}, target)
 
     def test_sync_zones(self):
         self.service._sync_zone = mock.Mock()
@@ -1938,7 +1916,7 @@ class CentralZoneTestCase(CentralBasic):
 
         t, ctx, target = designate.central.service.policy.check.call_args[0]
         self.assertEqual('diagnostics_sync_zone', t)
-        self.assertEqual({'tenant_id': 'tid',
+        self.assertEqual({'project_id': 'tid',
                           'zone_id': CentralZoneTestCase.zone__id,
                           'zone_name': 'n'}, target)
 
@@ -1965,7 +1943,7 @@ class CentralZoneTestCase(CentralBasic):
             'record_id': CentralZoneTestCase.record__id,
             'recordset_id': CentralZoneTestCase.recordset__id,
             'recordset_name': 'n',
-            'tenant_id': 'tid'}, target)
+            'project_id': 'tid'}, target)
 
     def test_ping(self):
         self.service.storage.ping.return_value = True
@@ -2118,7 +2096,7 @@ class CentralZoneExportTests(CentralBasic):
         n, ctx, target = designate.central.service.policy.check.call_args[0]
 
         # Check arguments to policy
-        self.assertEqual('t', target['tenant_id'])
+        self.assertEqual('t', target['project_id'])
 
         # Check output
         self.assertEqual(CentralZoneTestCase.zone__id, out.zone_id)
@@ -2190,13 +2168,20 @@ class CentralStatusTests(CentralBasic):
 class CentralQuotaTest(unittest.TestCase):
 
     def setUp(self):
+        self.CONF = cfg_fixture.Config(cfg.CONF)
+        cfg.CONF([], project='designate')
+        self.CONF.config(quota_driver="noop")
         self.context = mock.Mock()
         self.zone = mock.Mock()
+        self.quotas_of_one = {'zones': 1,
+                              'zone_recordsets': 1,
+                              'zone_records': 1,
+                              'recordset_records': 1,
+                              'api_export_size': 1}
 
     @patch('designate.central.service.storage')
     @patch('designate.central.service.quota')
     def test_zone_record_quota_allows_lowering_value(self, quota, storage):
-        cfg.CONF([], project='designate')
         service = Service()
         service.storage.count_records.return_value = 10
 
@@ -2220,6 +2205,100 @@ class CentralQuotaTest(unittest.TestCase):
 
         # Check the recordset limit as well
         check_recordset_records = mock.call(
-            self.context, self.zone.tenant_id, recordset_records=10
+            self.context, self.zone.tenant_id, recordset_records=5
         )
         assert check_recordset_records in service.quota.limit_check.mock_calls
+
+    @patch('designate.quota.base.Quota.get_quotas')
+    @patch('designate.central.service.storage')
+    def test_enforce_zone_quota(self, storage, mock_get_quotas):
+        service = Service()
+        mock_get_quotas.return_value = self.quotas_of_one
+
+        # Test creating one zone, 1 quota, no existing zones
+        service.storage.count_zones.return_value = 0
+        self.assertIsNone(service._enforce_zone_quota(self.context,
+                                                      'fake_project_id'))
+
+        # Test creating one zone, 1 quota, one existing zone
+        service.storage.count_zones.return_value = 1
+        self.assertRaises(exceptions.OverQuota, service._enforce_zone_quota,
+                          self.context, 'fake_project_id')
+
+    @patch('designate.quota.base.Quota.get_quotas')
+    @patch('designate.central.service.storage')
+    def test_enforce_recordset_quota(self, storage, mock_get_quotas):
+        service = Service()
+        mock_get_quotas.return_value = self.quotas_of_one
+
+        # Test creating one recordset, 1 quota, no existing recordsets
+        service.storage.count_recordsets.return_value = 0
+        self.assertIsNone(service._enforce_recordset_quota(self.context,
+                                                           self.zone))
+
+        # Test creating one recordset, 1 quota, one existing recordset
+        service.storage.count_recordsets.return_value = 1
+        self.assertRaises(exceptions.OverQuota,
+                          service._enforce_recordset_quota,
+                          self.context, self.zone)
+
+    @patch('designate.quota.base.Quota.get_quotas')
+    @patch('designate.central.service.storage')
+    def test_enforce_record_quota(self, storage, mock_get_quotas):
+        service = Service()
+        mock_get_quotas.return_value = self.quotas_of_one
+
+        service.storage.count_records.side_effect = [
+            0, 0,
+            1, 0,
+            0, 1,
+            1, 1,
+            1, 1,
+        ]
+
+        managed_recordset = mock.Mock()
+        managed_recordset.managed = True
+
+        recordset_one_record = mock.Mock()
+        recordset_one_record.managed = False
+        recordset_one_record.records = ['192.0.2.1']
+
+        # Test that managed recordsets have no quota limit
+        self.assertIsNone(service._enforce_record_quota(self.context,
+                                                        self.zone,
+                                                        managed_recordset))
+        service.storage.count_records.assert_not_called()
+
+        # Test creating recordset with one record, no existing zone records,
+        # no existing recordsets
+        self.assertIsNone(service._enforce_record_quota(self.context,
+                                                        self.zone,
+                                                        recordset_one_record))
+
+        # Test creating recordset with one record, one existing zone record,
+        # no exiting recordsets
+        self.assertRaises(exceptions.OverQuota, service._enforce_record_quota,
+                          self.context, self.zone, recordset_one_record)
+
+        # Test creating recordset with one record, one existing zone record,
+        # no exiting recordsets
+        # Note: Recordsets replace the existing recordset
+        self.assertIsNone(service._enforce_record_quota(self.context,
+                                                        self.zone,
+                                                        recordset_one_record))
+
+        # Test creating recordset with one record, no existing zone record,
+        # one exiting recordsets
+        # Note: Recordsets replace the existing recordset
+        self.assertIsNone(service._enforce_record_quota(self.context,
+                                                        self.zone,
+                                                        recordset_one_record))
+
+        recordset_two_record = mock.Mock()
+        recordset_two_record.managed = False
+        recordset_two_record.records = ['192.0.2.1', '192.0.2.2']
+
+        # Test creating recordset with two records, one existing zone record,
+        # one exiting recordsets
+        self.assertRaises(exceptions.OverQuota, service._enforce_record_quota,
+                          self.context, self.zone, recordset_two_record)
