@@ -20,10 +20,10 @@ import dns
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from designate.worker import utils as wutils
-from designate.worker.tasks import base
+from designate import dnsutils
 from designate import exceptions
 from designate import utils
+from designate.worker.tasks import base
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -88,17 +88,21 @@ class ZoneActionOnTarget(base.Task):
                           self.action, self.zone.name, self.target)
                 return True
             except Exception as e:
-                LOG.info('Failed to %(action)s zone %(zone)s on '
-                         'target %(target)s on attempt %(attempt)d, '
-                         'Error: %(error)s.',
-                         {
-                             'action': self.action,
-                             'zone': self.zone.name,
-                             'target': self.target.id,
-                             'attempt': retry + 1,
-                             'error': str(e)
-                         })
-                time.sleep(self.retry_interval)
+                LOG.info(
+                    'Failed to %(action)s zone_name=%(zone_name)s '
+                    'zone_id=%(zone_id)s on target=%(target)s on '
+                    'attempt=%(attempt)d Error=%(error)s',
+                    {
+                        'action': self.action,
+                        'zone_name': self.zone.name,
+                        'zone_id': self.zone.id,
+                        'target': self.target,
+                        'attempt': retry + 1,
+                        'error': str(e),
+                    }
+                )
+
+            time.sleep(self.retry_interval)
 
         return False
 
@@ -124,7 +128,7 @@ class SendNotify(base.Task):
         port = int(self.target.options.get('port'))
 
         try:
-            wutils.notify(self.zone.name, host, port=port)
+            dnsutils.notify(self.zone.name, host, port=port)
             LOG.debug('Sent NOTIFY to %(host)s:%(port)s for zone %(zone)s',
                       {
                           'host': host,
@@ -155,7 +159,7 @@ class ZoneActor(base.Task, ThresholdMixin):
              of targets (bool)
     """
     def __init__(self, executor, context, pool, zone):
-        self.executor = executor
+        super(ZoneActor, self).__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
@@ -311,7 +315,7 @@ class PollForZone(base.Task):
         self.ns = ns
 
     def _get_serial(self):
-        return wutils.get_serial(
+        return dnsutils.get_serial(
             self.zone.name,
             self.ns.host,
             port=self.ns.port
@@ -365,7 +369,7 @@ class ZonePoller(base.Task, ThresholdMixin):
              number of nameservers in the pool
     """
     def __init__(self, executor, context, pool, zone):
-        self.executor = executor
+        super(ZonePoller, self).__init__(executor)
         self.context = context
         self.pool = pool
         self.zone = zone
@@ -404,6 +408,10 @@ class ZonePoller(base.Task, ThresholdMixin):
                       {'zone': self.zone.name, 'n': retry + 1})
             time.sleep(retry_interval)
 
+            if not self.is_current_action_valid(self.context, self.zone.action,
+                                                self.zone):
+                break
+
         return query_result
 
     def _on_failure(self, error_status):
